@@ -1,6 +1,6 @@
 /***************************************************************************
- ** $Id: main.cpp,v 1.55 2008/06/27 21:31:53 hoganrobert Exp $
- *   Copyright (C) 2006 by Robert Hogan                                    *
+ ** $Id: main.cpp,v 1.59 2008/08/21 11:50:14 hoganrobert Exp $
+ *   Copyright (C) 2006 - 2008 Robert Hogan                                *
  *   robert@roberthogan.net                                                *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -24,6 +24,7 @@
 #include "crashhandler.h"
 #include "torkconfig.h"
 #include "functions.h"
+#include "newfirstrunwizard.h"
 #include <kapplication.h>
 #include <kaboutdata.h>
 #include <kcmdlineargs.h>
@@ -31,10 +32,13 @@
 #include <kconfigdialogmanager.h>
 
 static const char description[] =
-    I18N_NOOP("TorK - An Anonymity Manager for the KDE Desktop");
+    I18N_NOOP("<b>TorK - An Anonymity Manager for the KDE Desktop.</b>\n"
+              "This product is produced independently from the Tor anonymity\n"
+              "software and carries no guarantee from The Tor Project about\n"
+              "quality, suitability or anything else.");
 
 static const char version[] = "";
-static const char title[] = "TorK 0.29,1";
+static const char title[] = "TorK 0.29.2";
 
 static KCmdLineOptions options[] =
 {
@@ -55,7 +59,7 @@ static KCmdLineOptions options[] =
 int main(int argc, char **argv)
 {
     KAboutData about("tork", I18N_NOOP(title), version, description,
-    KAboutData::License_GPL, "(C) 2006 - 2007 Robert Hogan", 0, 0, "tork-users@lists.sf.net");
+    KAboutData::License_GPL, "(C) 2006 - 2008 Robert Hogan", 0, 0, "tork-users@lists.sf.net");
     about.addAuthor( "Robert Hogan", I18N_NOOP("Author and Maintainer"), "robert@roberthogan.net", "http://tork.anonymityanywhere.com" );
     about.addAuthor( "Corinna Habets", I18N_NOOP("Icons"), 0);
     about.addAuthor( "Contains code by: Matt Edman, Justin Hipple, Max Howell,", 0, "" );
@@ -85,11 +89,21 @@ int main(int argc, char **argv)
     //Check for the existence of anonymizable/helper programs first.
     QStringList programList;
     programList << "firefox" << "kopete" << "gaim" <<
-                               "pidgin" << "opera" << "konversation" 
-                            << "konsole" << "yakuake" << "xterm" 
-                            << "rxvt" << "gnome-terminal" << "gpg";
+                   "pidgin" << "opera" << "konversation"
+                << "konsole" << "yakuake" << "xterm" << "konqueror"
+                << "rxvt" << "gnome-terminal" << "gpg";
     TorkConfig::setAvailablePrograms(findPrograms(programList));
 
+    //Run the wizard if necessary, and exit TorK completely if the wizard is
+    //cancelled.
+    if (TorkConfig::user().isEmpty()){
+        FirstRunWizard wizard;
+        wizard.setCaption( i18n( "First-Run Wizard" ));
+        if (wizard.exec() == QDialog::Rejected) {
+                TorkConfig::setUser("");
+                return 0;
+        }
+    }
 
     // see if we are starting with session management
     tork *widget = new tork;
