@@ -1,6 +1,6 @@
 /***************************************************************************
- ** $Id: newfirstrunwizard.ui.h,v 1.25 2008/06/02 10:38:26 hoganrobert Exp $
- *   Copyright (C) 2006 by Robert Hogan                                    *
+ ** $Id: newfirstrunwizard.ui.h,v 1.28 2008/08/22 13:37:37 hoganrobert Exp $
+ *   Copyright (C) 2006 - 2008 Robert Hogan                                *
  *   robert@roberthogan.net                                                *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -480,6 +480,7 @@ void FirstRunWizard::testTor()
 
     client = new TorClient(host,port);
     connect( client, SIGNAL(fatalError()),this, SLOT(cannotContactTor()));
+    connect( client, SIGNAL(authenticationFailed()),this, SLOT(cannotContactTor()));
     connect( client, SIGNAL(authenticated()),this, SLOT(contactedTor()) );
     client->authenticate();
 
@@ -494,6 +495,7 @@ void FirstRunWizard::cannotContactTor()
 {
 
     disconnect( client, SIGNAL(fatalError()),this, SLOT(cannotContactTor()));
+    disconnect( client, SIGNAL(authenticationFailed()),this, SLOT(cannotContactTor()));
     disconnect( client, SIGNAL(authenticated()),this, SLOT(contactedTor()) );
     if (client != 0L){
         client->socketReadyRead();
@@ -508,15 +510,15 @@ void FirstRunWizard::cannotContactTor()
             "<br>"
             "<b>ControlPort %2</b><br>"
             "<br>"
-            "Alternatively, you may have entered the wrong password in the previous page."
-            "When you've attempted to fix the problem, click 'Test Tor' to try connecting again.")
+            "Alternatively, you may have entered the wrong password in the previous page.<br>"
+            "When you've attempted to fix the problem, click <b>'Test Tor'</b> to try connecting again.")
             .arg(RemoteTorPort->text()));
     }else{
-        torControlStatus->setText(i18n("<p>I can't contact Tor.<br>"
+        torControlStatus->setText(i18n("<p>I can't contact or authenticate to Tor.<br>"
             "This means Tork will need to modify Tor's settings if it is to be usable by Tork in future.</p>"
             "To the right is a list of the possible files that Tor may be using for it's configuration.<br>"
-            "If you click the 'Modify Tor's Control File' button, I'll modify any that exist to make Tor controllable by TorK.<br>"
-            "Once that's done you can click 'Test Tor' to re-test the connection."));
+            "If you click the <b>'Modify Tor's Control File'</b> button, I'll modify any that exist to make Tor controllable by TorK.<br>"
+            "Once that's done you can click <b>'Test Tor'</b> to re-test the connection."));
         modifyConfigs->setEnabled(true);
     }
     testTorAgain->setEnabled(true);
@@ -542,7 +544,7 @@ void FirstRunWizard::contactedTor()
             "Tor that will secure it even when you're not using TorK.<br>"
             "See the 'My Tor Client' configuration section for more info"
             " when you're finished the wizard. <br>"
-            "You can now click 'Next'."));
+            "You can now click <b>'Next'</b>."));
     else
         torControlStatus->setText(i18n("<p>I contacted Tor successfully.<br>"
             "This means TorK can contact and control Tor. That's a good thing. "
@@ -573,17 +575,16 @@ void FirstRunWizard::examineConfigFiles()
     }
 
     if (!foundone){
-/*        torControlStatus->setText(i18n("<p>OK, I've modified a config file and asked Tor to reload.<br>"
-            "Click 'Test Tor' to see if the change worked."));
-    }else{*/
         appendControlDirective("/usr/local/etc/tor/torrc");
+        appendControlDirective("/etc/tor/torrc");
+        appendControlDirective("/usr/etc/tor/torrc");
         torControlStatus->setText(i18n("<p>OK, I didn't find any of the config files in the list.<br>"
-            "To make tor usable I've created a config file called /usr/local/etc/tor/torrc."
-            "I've also asked Tor to reload and catch the new config file. "
-            "<b> You'll be asked for yout root password in a moment. "
+            "To make tor usable I'm creating config files in three locations: /usr/local/etc/tor/torrc, /usr/etc/tor/torrc and /etc/tor/torrc."
+            "I've also asked Tor to reload and it will catch and use one of these files. "
+            "<b> You'll be asked for your root password in a moment. "
             "<b> This is to modify the file and necessary to get Tor working.</b> "
             "When you've entered your password "
-            "click 'Test Tor' to see if it worked. "));
+            "click <b>'Test Tor'</b> to see if it worked. "));
     }
 }
 
@@ -599,7 +600,7 @@ void FirstRunWizard::rootifyNetstat()
 
     KProcIO *catproc = new KProcIO();
     catproc->setUseShell(TRUE);
-    QString whichCommand= QString("kdesu -c 'cp %1 %2;chmod u+s %3'").arg(netstat).arg(newnetstat).arg(newnetstat);
+    QString whichCommand= QString("kdesu -t -c 'cp %1 %2;chmod u+s %3'").arg(netstat).arg(newnetstat).arg(newnetstat);
     *catproc<<whichCommand;
     catproc->start(KProcIO::NotifyOnExit,TRUE);
 
@@ -623,7 +624,7 @@ void FirstRunWizard::appendControlDirective(const QString& text)
                  i18n( "<p>I'm going to modify the Tor configuration file: <b>%1</b>.<br>"
                   "This is so that I can ensure"
                   "TorK can communicate with Tor.<br>"
-                  " If you say Yes, I'll ask for your root password.").arg(text));
+                  " If you say Yes, I may have to ask for your <b>root password</b>.").arg(text));
     switch (result) {
         case KMessageBox::No : 
             return;
@@ -635,19 +636,20 @@ void FirstRunWizard::appendControlDirective(const QString& text)
         QTextStream ts( &inf );
 
         ts << "ControlPort 9051" << "\n";
-//         ts << "CookieAuthentication 1" << "\n";
 
         inf.close();
         sighupTor("tor");
 
     }else{
 
+		QString directory = KURL(text).directory();
         KProcIO *catproc = new KProcIO();
         catproc->setUseShell(TRUE);
-        QString whichCommand= QString("kdesu -c 'printf \"ControlPort 9051\\n\""
-                                      " >> %1;killall -s HUP tor'").arg(text);
+        QString whichCommand= QString("kdesu -c \"sh -c 'mkdir -p %1;printf \\\"ControlPort 9051\\n\\\""
+                                      " >> %2;killall -s HUP tor'\"").arg(directory).arg(text);
         *catproc<<whichCommand;
         catproc->start(KProcIO::NotifyOnExit,TRUE);
+	//-c "sh -c 'printf \"ControlPort 9051\n\" >> /etc/tor/torrc'"
 
     }
 
@@ -756,8 +758,8 @@ void FirstRunWizard::appendPrivoxyConfig(const QString& text)
 
         KProcIO *catproc = new KProcIO();
         catproc->setUseShell(TRUE);
-        QString whichCommand= QString("kdesu -c 'printf \"%1\""
-                                      " >> %2;killall -s HUP privoxy'")
+        QString whichCommand= QString("kdesu -c \"sh -c 'printf \\\"%1\\\""
+                                      " >> %2;killall -s HUP privoxy'\"")
                                       .arg(privoxyConf)
                                       .arg(text);
         *catproc<<whichCommand;
