@@ -1,7 +1,7 @@
 /****************************************************************************
- ** $Id: torclient.cpp,v 1.125 2008/07/06 09:49:27 hoganrobert Exp $
- *   Copyright (C) 2006 by Robert Hogan   *
- *   robert@roberthogan.net   *
+ ** $Id: torclient.cpp,v 1.132 2008/08/22 13:37:37 hoganrobert Exp $
+ *   Copyright (C) 2006 - 2008 Robert Hogan                                *
+ *   robert@roberthogan.net                                                *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -16,7 +16,7 @@
  *   You should have received a copy of the GNU General Public License     *
  *   along with this program; if not, write to the                         *
  *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.            *
+ *   51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.              *
  ***************************************************************************/
 
 
@@ -336,6 +336,13 @@ void TorClient::slotCheckGuards()
 
 }
 
+void TorClient::terminateTor()
+{
+
+    sendToServer("SIGNAL SHUTDOWN");
+
+}
+
 void TorClient::createService(const QString &dir, const QString &port)
 {
     sendToServer(QString("setconf hiddenservicedir=\"%1\" hiddenserviceport=\"%2\"").arg(dir).arg(port));
@@ -627,7 +634,8 @@ void TorClient::socketReadyRead()
                 else
                     emit processWarning("authenticationfailed", eventInfo);
             }
-            emit fatalError();
+			//Only used by the first-run wizard
+            emit authenticationFailed();
         }
 
 
@@ -795,6 +803,10 @@ void TorClient::parseStream(const QString &info)
     QString circID = info.section(" ",2,2);
     QString Target = info.section(" ",3,3);
 
+    //We ignore REMAPs because we don't do anything with them
+    if (status == "REMAP")
+        return;
+
     emit streamStatusUpdate(streamID, status, circID, Target, info);
 
 }
@@ -912,12 +924,22 @@ void TorClient::parseServer(const QString &info)
 void TorClient::parseAddrmap(const QString &info)
 {
 
-    if (!m_resolvingServerAddress)
-        return;
 
     QString type = info.section(" ",0,0);
     QString address = info.section(" ",1,1);
 
+    // If this is a request to resolve a hostname/address from the traffic
+    // logs
+    if (logResolveList.contains(type)){
+        emit resolvedAddress(info);
+        logResolveList.remove(logResolveList.find(type));
+        return;
+    }
+
+    if (!m_resolvingServerAddress)
+        return;
+
+    // If this is a request to resolve a node name from the server list
     if (type.startsWith("REVERSE")){
         m_statustiptmp.replace("$HOSTNAME",address);
     }else
@@ -1479,4 +1501,20 @@ void TorClient::allowPlainTextPorts()
                 .arg(m_portsToReject.join(",")));
 }
 
+void TorClient::resolveAddress(const QString &address)
+{
+    QRegExp rx("[0-9]{1,3}\\.[0-9]{1,3}\\.[0-9]{1,3}\\.[0-9]{1,3}");
+    rx.search(address);
+    QString tmp = rx.cap(0);
+    if (tmp.isEmpty()) {
+      sendToServer("RESOLVE " + address);
+      logResolveList << address;
+    }else{
+      sendToServer("RESOLVE mode=reverse " + tmp);
+      logResolveList << QString("REVERSE[%1]").arg(tmp);
+    }
+
+}
+
 #include "torclient.moc"
+
