@@ -1,7 +1,7 @@
 /****************************************************************************
- ** $Id: torclient.h,v 1.69 2008/06/02 10:38:26 hoganrobert Exp $
- *   Copyright (C) 2006 by Robert Hogan   *
- *   robert@roberthogan.net   *
+ ** $Id: torclient.h,v 1.74 2008/08/22 13:37:37 hoganrobert Exp $
+ *   Copyright (C) 2006 - 2008 Robert Hogan                                *
+ *   robert@roberthogan.net                                                *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -16,7 +16,7 @@
  *   You should have received a copy of the GNU General Public License     *
  *   along with this program; if not, write to the                         *
  *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.            *
+ *   51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.              *
  ***************************************************************************
 **
 ** Copyright (C) 1992-2000 Trolltech AS.  All rights reserved.
@@ -125,12 +125,13 @@ signals:
     void connectedToTor( );
     void authenticated();
     void streamBwUpdate(const QString &,const QString &,const QString & );
-    void streamProgram(const QString &,const QString &);
     void setTorCaption(const QString &);
     void processWarning(const QString &,const QString &);
     void processQuestion(const QString &,const QString &);
     void showServerBW(const QString&);
     void updateTrayIcon(const QString&);
+    void resolvedAddress(const QString&);
+	void authenticationFailed();
 
 public slots:
     void socketReadyRead();
@@ -156,6 +157,8 @@ public slots:
     void closeAllCircuits( QListView* &circuitList);
     void allowPlainTextPorts( );
     void assignPortToRemove();
+    void resolveAddress(const QString &);
+    void terminateTor();
 
 private slots:
     void closeConnection()
@@ -257,7 +260,7 @@ private:
     QStringList m_WarnedPorts;
     QStringList m_portsToReject;
     QString m_portToRemove;
-
+    QStringList logResolveList;
 };
 
 #endif //
