@@ -1,6 +1,6 @@
 /***************************************************************************
- * $Id: tork.h,v 1.106 2008/06/08 21:05:11 hoganrobert Exp $
- *   Copyright (C) 2006 by Robert Hogan                                    *
+ * $Id: tork.h,v 1.113 2008/10/14 18:12:31 hoganrobert Exp $
+ *   Copyright (C) 2006 - 2008 Robert Hogan                                *
  *   robert@roberthogan.net                                                *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -38,6 +38,7 @@
 #include "torkconfig.h"
 #include "version.h"
 #include "dcoptork.h"
+#include "testprivacyproxy.h"
 
 #include <kconfigskeleton.h>
 #include <kwinmodule.h>
@@ -68,6 +69,8 @@ class KWindModule;
 class UPnPManager;
 class SetMaxRate;
 class MyHidden;
+class TestProxy;
+
 //class QValueVector;
 
 /** Enumeration of types which option values can take */
@@ -122,6 +125,7 @@ public:
 
     QStringList getDiscoveredRouters(){ return discoveredRouters;};
     void setBandwidthFromSysTray(int rate );
+    void enableKDEAndLaunchKonqWithUrl(const QString &);
 
 private slots:
     void fileNew();
@@ -148,7 +152,6 @@ private slots:
     void changeCaption(const QString& text);
     void startController();
     void stopController();
-    void startEverything();
     void receivedOutput(KProcIO *);
     void processFilter(KProcIO *filterproc);
     void receivedNetStatOutput(KProcIO *);
@@ -188,6 +191,7 @@ private slots:
     void startingPeriodOver();
     void needAlphaVersion( );
     void filterServers( int );
+    void toggleIP( int );
     void filterLog( int );
     void filterSubnets( int );
     void filterCountries( int );
@@ -216,9 +220,14 @@ private slots:
     void upnpForwardingError(kt::UPnPRouter*,const QString &, bool);
     void routerDiscovered(kt::UPnPRouter* );
     void configureRouter(bool force,bool silent=false);
+    void checkForSystemManagedPrivoxy();
+    void cannotContactPrivoxy();
+    void privacyProxyPassed();
+
 public slots:
 
     void startPrivoxy();
+    void letTorKManagePrivoxy();
     void serverHelp(); 
     void enterContactInfo();
     void fixAddressPort();
@@ -261,6 +270,8 @@ public slots:
     void retryUPnP();
     void allowPlainTextPorts();
     void assignPortToRemove();
+    void startEverything();
+    void stopTorGracefully();
 
 private:
     void setupAccel();
@@ -388,6 +399,9 @@ private:
     bool m_showstopperAlreadyDisplayed;
     bool m_routerDiscovered;
     bool recentNewIdentityRequest;
+    bool m_ShutdownRequested;
+    bool m_AppliedSettings;
+    bool m_CanApplyServerSettingsIfSet;
 
     QDialog* dialog;
     MyHidden* myHiddenDialog;
@@ -402,6 +416,8 @@ private:
 
 	SetMaxRate* m_set_max_rate;
 
+    TestPrivoxy *privoxytest;
+
 };
 
 
