@@ -1,7 +1,7 @@
 /***************************************************************************
- ** $Id: torkview.cpp,v 1.115 2008/06/08 21:05:11 hoganrobert Exp $
- *   Copyright (C) 2006 by Robert Hogan   *
- *   robert@roberthogan.net   *
+ ** $Id: torkview.cpp,v 1.122 2008/08/20 16:49:31 hoganrobert Exp $
+ *   Copyright (C) 2006 - 2008 Robert Hogan                                *
+ *   robert@roberthogan.net                                                *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -66,19 +66,10 @@
 /* Linux-specific includes */
 #include <dirent.h>
 #include <unistd.h>
+#include "../config.h"
 
 using namespace tk;
 
-typedef QMap<QString, streamItem*> streamlist;
-streamlist streams;
-typedef QMap<QString, QListViewItem*> osdstreamlist;
-osdstreamlist osdstreams;
-typedef QMap<QString, QListViewItem*> circuitExitList;
-circuitExitList circuitExits;
-
-typedef QMap<QString, int> streamBw;
-streamBw streamBwIn;
-streamBw streamBwOut;
 
 #define MAX_BW_RATE 2
 #define MAX_CG_RATE 60*5
@@ -171,9 +162,21 @@ torkView::torkView(QWidget *parent)
     connect(this, SIGNAL(updateStats()), chart, SLOT(update()));
 
 
-    m_osd = new StreamOSD(this );
+    m_osd = new StreamOSD(this, true);
     m_osd->readSettings(KGlobal::config());
 
+    m_nontorosd = new StreamOSD(this, false);
+    m_nontorosd->readSettings(KGlobal::config());
+
+    //Icons showing the status of the stream
+    streamStatusIcon["SUCCEEDED"] = QPixmap(SmallIcon("tork_green"));
+    streamStatusIcon["FAILED"] = QPixmap(SmallIcon("tork_red"));
+    streamStatusIcon["SENTCONNECT"] = QPixmap(SmallIcon("tork_yellow"));
+    streamStatusIcon["SENTRESOLVE"] = QPixmap(SmallIcon("tork_orange"));
+    streamStatusIcon["NEW"] = QPixmap(SmallIcon("tork_little"));
+    streamStatusIcon["DETACHED"] = QPixmap(SmallIcon("tork_little"));
+    streamStatusIcon["CLOSED"] = QPixmap(SmallIcon("tork_todelete"));
+    progDisplayCounter = 0;
 }
 
 void torkView::resetBWHistory() {
@@ -218,13 +221,28 @@ void torkView::clearStreamMaps() {
 
     streams.clear();
     osdstreams.clear();
+    circuitExits.clear();
     streamBwIn.clear();
     streamBwOut.clear();
+    logstreams.clear();
+    cachedStreamIcon.clear();
+    torservers.clear();
 }
 
 void torkView::downloadTorButton() {
 
-    anonymizedFirefox( "http://torbutton.torproject.org/dev/torbutton-current-alpha.xpi");
+    int result = KMessageBox::questionYesNo(0,
+                 i18n( "<p>Once you install TorButton, restart Firefox from here "
+                 "rather than letting Firefox restart automatically. This will"
+                 " ensure you do not browse with your normal Firefox "
+                 "profile.<br> <b>Continue?</b></p>")
+                 ,i18n( "Be sure to restart Firefox from Tork!" ));
+
+    switch (result) {
+      case KMessageBox::Yes : 
+        anonymizedFirefox( "http://www.torproject.org/torbutton/torbutton-current.xpi");
+    }
+
 }
 
 void torkView::downloadMixminion() {
@@ -514,7 +532,7 @@ void torkView::toggleParanoidMode(int id)
     switch(id)
     {
     case 0:
-        paranoidmodeicon->setPixmap(SmallIcon("penguin"));
+        paranoidmodeicon->setPixmap(SmallIcon("tork_penguin"));
         paranoidmodetext->setText(i18n("In Normal mode!"));
         break;
     case 1:
@@ -622,206 +640,248 @@ torkView::~torkView()
 
 }
 
+#define MAXPROGDISPLAY 5
+
 void torkView::streamStatusUpdated(const QString &streamID, const QString &status,
         const QString &circID, const QString &Target, const QString &info)
 {
 
 
-    QString tmpstatus = status.lower().stripWhiteSpace();
+  QString tmpstatus = status.stripWhiteSpace();
 
-    m_osd->setShown(m_tormon);
-    m_osd->infoList->adjustColumn(1);
-    infoList->adjustColumn(2);
+  streamItem* streamline;
+  QListViewItem* osdstreamline;
+  QListViewItem* torTrafficLine;
 
-    streamItem* streamline;
-    QListViewItem* osdstreamline;
-    QListViewItem* torTrafficLine;
+  torTrafficLine=0L;
 
-    torTrafficLine=0L;
+  if (!(streamline = streams[streamID])){
+    if (!(tmpstatus == "CLOSED") && !(tmpstatus == "FAILED")){
+      m_osd->setShown(m_tormon);
+      m_osd->infoList->adjustColumn(1);
+      infoList->adjustColumn(2);
 
-    if (!(streamline = streams[streamID])){
-        if (!(tmpstatus == "closed") && !(tmpstatus == "failed")){
-            timeLastTorUse = QTime::currentTime();
+      timeLastTorUse = QTime::currentTime();
 
-            QString cleanedFullTarget = Target;
-            cleanedFullTarget.replace(QRegExp("(\\.\\$[A-Z0-9]{40})\\."),".");
-            QString cleanedTarget = cleanedFullTarget.section(":",0,0);
-            QString cleanedPort = cleanedFullTarget.section(":",1,1);
-            addrLastTorUse = cleanedFullTarget;
+      QString cleanedFullTarget = Target;
+      cleanedFullTarget.replace(QRegExp("(\\.\\$[A-Z0-9]{40})\\."),".");
+      QString cleanedTarget = cleanedFullTarget.section(":",0,0);
+      QString cleanedPort = cleanedFullTarget.section(":",1,1);
+      addrLastTorUse = cleanedFullTarget;
 
-            if (TorkConfig::paranoidMode() > 0)
-                emit newIdentity();
+      if (TorkConfig::paranoidMode() > 0)
+          emit newIdentity();
 
-            //log entry
-            if (TorkConfig::logTorTraffic())
-                torTrafficLine = new QListViewItem(TorTraffic, streamID, QDateTime::currentDateTime ().toString(Qt::ISODate).replace("T"," "), cleanedFullTarget);
+      // Find the program associated with the stream
+      QString program = "..";
+      QPixmap programicon;
 
-            
-            streamline = new streamItem(streamList, streamID, "", cleanedFullTarget,"","0 B/s",circID, "Pending..");
-            osdstreamline = new QListViewItem(m_osd->infoList,streamID, cleanedTarget,"","0 B/s",circID);
-            streams[streamID] = streamline;
-            osdstreams[streamID] = osdstreamline;
+      if ((tmpstatus == "NEW")){
+          if (info.contains("PURPOSE=USER")){
+              QRegExp rx("(SOURCE_ADDR=127.0.0.1:[0-9]+ )");
+              rx.search(info);
+              QString port = rx.cap(0).section("SOURCE_ADDR=127.0.0.1:",-1)
+                                 .stripWhiteSpace();
+              portStream[streamID] = port;
+          }else{
+              QString purpose = info.section("PURPOSE=",-1,-1);
+              program = streamPurpose[purpose];
+              programicon = QPixmap(SmallIcon("tork_tor"));
+          }
+      }
 
-            if (tmpstatus == "new"){
- 
-                if (info.contains("PURPOSE=USER")){
-                    QRegExp rx("(SOURCE_ADDR=127.0.0.1:[0-9]+ )");
-                    rx.search(info);
-                    kdDebug() << rx.cap(0) << endl;
-                    QString port = rx.cap(0).section("SOURCE_ADDR=127.0.0.1:",-1)
-                                       .stripWhiteSpace();
-                    parseStreamPort(streamID,port);
-                }else{
-                    QString purpose = info.section("PURPOSE=",-1,-1);
-                    streamline->setText(1,streamPurpose[purpose]);
-                    streamline->setPixmap(1,QPixmap(SmallIcon("tork_tor")));
+      // Assign the circuit and exit server to the stream
+      circuitItem* circuitline;
+      QString circuit = "Pending..";
+      QString exitserver;
+      QPixmap exitserverflag;
+      // Don't look for circuit if one hasn't been assigned yet
+      if (circID != "0") {
+        if ((circuitline = (circuitItem*)
+                           circuitList->findItem(circID,0)) != 0){
+          QListViewItem* serverline;
+          if ((serverline = (QListViewItem*) circuitExits[circID]) != 0){
+              exitserver = serverline->text(1);
+              exitserverflag = *serverline->pixmap(1);
+          }
+          circuit = circuitline->text(2);
+        }
+      }
+
+      //Assign an icon to illustrate the type of stream
+      QPixmap icon = cachedStreamIcon[cleanedFullTarget];
+      if (icon.isNull()){
+
+        QString iconPath = locate("cache",
+                          KMimeType::favIconForURL("http://"+cleanedTarget)
+                          +".png");
+
+        if (!iconPath.isEmpty()){
+
+            icon.load( iconPath );
+            if (cleanedPort == "443"){
+                QPixmap overlay = KSystemTray::loadIcon( "tork_ssl" );
+
+                if ( !overlay.isNull() )
+                {
+                  int x = icon.width() - overlay.width();
+                  int y = icon.height() - overlay.height();
+                  if ( icon.mask() )
+                  {
+                    QBitmap mask = *icon.mask();
+                    bitBlt( &mask, x, y,
+                            overlay.mask() ?
+                            const_cast<QBitmap*>(overlay.mask()) : &overlay,
+                            0, 0, overlay.width(), overlay.height(),
+                            overlay.mask() ? OrROP : SetROP );
+                    icon.setMask(mask);
+                  }
+                  bitBlt( &icon, x, y, &overlay );
                 }
             }
 
-            circuitItem* circuitline;
-            if ((circuitline = (circuitItem*) circuitList->findItem(circID,0)) == 0){
-                streamline->setText(5,circID);
-                if (TorkConfig::logTorTraffic()) torTrafficLine->setText(3,circID);
-                if (osdstreamline) osdstreamline->setText(4,circID);
-            }else{
-                QListViewItem* serverline;
-                if ((serverline = (QListViewItem*) circuitExits[circID]) != 0){
-                    streamline->setText(5,serverline->text(1));
-                    streamline->setPixmap( 5, *serverline->pixmap(1) );
-                    if (osdstreamline){
-                        osdstreamline->setText(4,serverline->text(1));
-                        osdstreamline->setPixmap( 4, *serverline->pixmap(1) );
-                    }
-                }
-               streamline->setText(6,circuitline->text(2));
-                if (TorkConfig::logTorTraffic()) 
-                    torTrafficLine->setText(3,circuitline->text(2));
-            }
-
-            QString iconPath = locate("cache",
-                               KMimeType::favIconForURL("http://"+cleanedTarget)
-                               +".png");
-
-
-            if (!iconPath.isEmpty()){
-
-                QPixmap icon( iconPath );
-                if (cleanedPort == "443"){
-                    QPixmap overlay = KSystemTray::loadIcon( "tork_ssl" );
-
-                    if ( !overlay.isNull() )
-                    {
-                      int x = icon.width() - overlay.width();
-                      int y = icon.height() - overlay.height();
-                      if ( icon.mask() )
-                      {
-                        QBitmap mask = *icon.mask();
-                        bitBlt( &mask, x, y,
-                                overlay.mask() ?
-                                const_cast<QBitmap*>(overlay.mask()) : &overlay,
-                                0, 0, overlay.width(), overlay.height(),
-                                overlay.mask() ? OrROP : SetROP );
-                        icon.setMask(mask);
-                      }
-                      bitBlt( &icon, x, y, &overlay );
-                    }
-                }
-
-                streamline->setPixmap( 2, icon );
-                osdstreamline->setPixmap( 1, icon );
-                if (TorkConfig::logTorTraffic()) 
-                    torTrafficLine->setPixmap( 2, icon );
-            }else{
-                int i;
-                for (i = 0; _port_icon[i].port; ++i) {
-                    portsandicons_t *pics = &_port_icon[i];
-                    if (cleanedPort == pics->port){
-                        streamline->setPixmap( 2, SmallIcon(pics->icon) );
-                        osdstreamline->setPixmap( 1, SmallIcon(pics->icon) );
-                        if (TorkConfig::logTorTraffic()) 
-                            torTrafficLine->setPixmap( 2, SmallIcon(pics->icon) );
-                        if ((!pics->secure) && (!pics->display)){
-                            pics->display = DONT_DISPLAY_AGAIN;
-                            if (pics->screaminglyinsecure)
-                                emit showScreamingNotice(cleanedPort);
-                            else
-                                emit showSecurityNotice(cleanedPort);
-                        }
+        }else{
+            int i;
+            for (i = 0; _port_icon[i].port; ++i) {
+                portsandicons_t *pics = &_port_icon[i];
+                if (cleanedPort == pics->port){
+                    icon = SmallIcon(pics->icon);
+                    if ((!pics->secure) && (!pics->display)){
+                        pics->display = DONT_DISPLAY_AGAIN;
+                        if (pics->screaminglyinsecure)
+                            emit showScreamingNotice(cleanedPort);
+                        else
+                            emit showSecurityNotice(cleanedPort);
                     }
                 }
             }
-
-            streamline->setDragEnabled(true);
-            streamline->setDropEnabled(true);
-
-            for( uint index = 0; index < iconList.count(); index++ ) {
-                if ( iconList[index].contains(tmpstatus)) {
-                    streamline->setPixmap(3,QPixmap(SmallIcon("tork_"+iconList[index].first())));
-                    osdstreamline->setPixmap(2,QPixmap(SmallIcon("tork_"+iconList[index].first())));
-                    break;
-                }
-            }
-
         }
+        cachedStreamIcon[cleanedFullTarget] = icon;
+      }
 
-    }else{
+      //Assign an icon to illustrate the stream status
+      QPixmap statusicon = streamStatusIcon[tmpstatus];
 
+      //Display the entries in the UI
 
-        //osdstreamline = (QListViewItem*)m_osd->infoList->findItem(streamID,0);
-        osdstreamline = osdstreams[streamID];
+      //Add to the traffic log if necessary
+      if (TorkConfig::logTorTraffic()){
+        torTrafficLine = new QListViewItem(TorTraffic, streamID,
+                                           QDateTime::currentDateTime().
+                                            toString(Qt::ISODate).
+                                            replace("T"," "),
+                                           cleanedFullTarget,
+                                           circuit);
+        torTrafficLine->setPixmap( 2, icon );
+      }
 
-        for( uint index = 0; index < iconList.count(); index++ ) {
-            if ( iconList[index].contains(tmpstatus)) {
-                streamline->setPixmap(3,QPixmap(SmallIcon("tork_"+iconList[index].first())));
-                if (osdstreamline) osdstreamline->setPixmap(2,QPixmap(SmallIcon("tork_"+iconList[index].first())));
-                continue;
-            }
-        }
+      // The stream in the 'Connections' Pane
+      streamline = new streamItem(streamList, streamID, program,
+                                  cleanedFullTarget, "",
+                                  "0 B/s", exitserver,
+                                  circuit);
+      streamline->setPixmap(1,programicon);
+      streamline->setPixmap(2,icon);
+      streamline->setPixmap(3,statusicon);
+      streamline->setPixmap(5,exitserverflag);
+      streamline->setDragEnabled(true);
+      streamline->setDropEnabled(true);
 
+      //The stream in the OSD display
+      osdstreamline = new QListViewItem(m_osd->infoList,streamID,
+                                        cleanedTarget,"","0 B/s", circuit);
+      osdstreamline->setPixmap(2,statusicon);
+      osdstreamline->setPixmap(1,icon);
 
-        if (status == "CLOSED"){
-            delete streamline;
-            streams.erase(streamID);
-            streamBwIn.erase(streamID);
-            streamBwOut.erase(streamID);
-            if (osdstreamline) delete osdstreamline;
-            osdstreams.erase(streamID);
-            return;
-        }
+      // Cache for quick reference
+      streams[streamID] = streamline;
+      osdstreams[streamID] = osdstreamline;
+      logstreams[streamID] = torTrafficLine;
 
-        // If the stream does not have a verbose circuit description, add one
-        if ((streamline->text(6) == "Pending..")){ 
-
-            if (TorkConfig::logTorTraffic()) 
-                torTrafficLine = (QListViewItem*)TorTraffic->findItem(streamID,0);
-
-            circuitItem* circuitline;
-            if ((circuitline = (circuitItem*) circuitList->findItem(circID,0)) == 0){
-                streamline->setText(5,circID);
-                if (osdstreamline) osdstreamline->setText(4,circID);
-                if (TorkConfig::logTorTraffic() && (torTrafficLine) && (circID != "0")) torTrafficLine->setText(3,circID);
-            }else{
-                QListViewItem* serverline;
-                if ((serverline = (QListViewItem*) circuitExits[circID]) != 0){
-                    streamline->setText(5,serverline->text(1));
-                    streamline->setPixmap( 5, *serverline->pixmap(1) );
-                    if (osdstreamline){
-                        osdstreamline->setText(4,serverline->text(1));
-                        osdstreamline->setPixmap( 4, *serverline->pixmap(1) );
-                    }
-                }
-                streamline->setText(6,circuitline->text(2));
-                if (TorkConfig::logTorTraffic() && torTrafficLine)
-                   torTrafficLine->setText(3,circuitline->text(2));
-            }
-        }
 
     }
 
+  }else{
+
+      osdstreamline = osdstreams[streamID];
+
+      if (tmpstatus == "CLOSED"){
+          kdDebug() << "progcnt: " << progDisplayCounter << endl;
+          if ((streamline->text(1) != "..") &&
+             (progDisplayCounter > 0))
+              progDisplayCounter--;
+          streams.erase(streamID);
+          streamBwIn.erase(streamID);
+          streamBwOut.erase(streamID);
+          osdstreams.erase(streamID);
+          portStream.erase(streamID);
+          logstreams.erase(streamID);
+          if (osdstreamline) delete osdstreamline;
+          delete streamline;
+          return;
+      }
+
+      QPixmap statusicon = streamStatusIcon[status.stripWhiteSpace()];
+      streamline->setPixmap(3,statusicon);
+      osdstreamline->setPixmap(2,statusicon);
+
+
+      // If the stream does not have a verbose circuit description, add one
+      if ((streamline->text(6) == "Pending..")){
+
+          QString circuit = "Pending..";
+          QString exitserver;
+          QPixmap exitserverflag;
+
+          circuitItem* circuitline;
+          // Don't look for circuit if one hasn't been assigned yet
+          if (circID != "0") {
+            if ((circuitline = (circuitItem*) circuitList->findItem(circID,0)) != 0){
+                QListViewItem* serverline;
+                if ((serverline = (QListViewItem*) circuitExits[circID]) != 0){
+                    exitserver = serverline->text(1);
+                    exitserverflag = *serverline->pixmap(1);
+                }
+                circuit = circuitline->text(2);
+            }
+
+            if ((torTrafficLine = logstreams[streamID])){
+                torTrafficLine->setText(3,circuit);
+            }
+
+            streamline->setText(6, circuit);
+            streamline->setPixmap(5,exitserverflag);
+            streamline->setText(5,exitserver);
+
+            osdstreamline->setPixmap(4,exitserverflag);
+            osdstreamline->setText(4,exitserver);
+          }
+      }
+
+      if (tmpstatus == "SUCCEEDED"){
+        //HACK: this is too process intensive if there are many short-lived
+        //      streams so we only look for the program if we aren't
+        //      already displaying it in MAXPROGDISPLAY streams and there's 
+        //      less than MAXPROGDISPLAY * 3 streams active in total.
+        //      There's also no point in looking up the program unless
+        //      the connection is successful
+        if (streamline->text(1) == ".."){
+          if ((streamList->childCount() < (MAXPROGDISPLAY * 3))
+             && (progDisplayCounter < MAXPROGDISPLAY)) {
+            QString program = parseStreamPort(portStream[streamID]);
+            QPixmap programicon = streamProgram(program);
+            streamline->setText(1,program);
+            streamline->setPixmap(1,programicon);
+            progDisplayCounter++;
+          }
+        }
+      }
+  }
+
 
 }
 
-void torkView::parseStreamPort(const QString &stream, const QString &str_port)
+QString torkView::parseStreamPort(const QString &str_port)
 {
 
     int m_port = str_port.toInt();
@@ -857,7 +917,7 @@ void torkView::parseStreamPort(const QString &stream, const QString &str_port)
     }
     
     if (inode.isEmpty())
-        return;
+        return QString();
 
     QDir d = QDir( "/proc" );
     QStringList dirs = d.entryList( QDir::Dirs );
@@ -895,7 +955,7 @@ void torkView::parseStreamPort(const QString &stream, const QString &str_port)
                 QString program = t.readLine();
                 program.replace('\0',' ');
                 program = program.section(" ",0,0).section("/",-1);
-                emit streamProgram(stream, program);
+                return program;
 
             }
         }
@@ -903,7 +963,7 @@ void torkView::parseStreamPort(const QString &stream, const QString &str_port)
 
         if (foundIt) break;
     }
-
+    return QString();
 }
 
 void torkView::circuitStatusUpdated(const QString &circuitID, const QString &status, const QString &server, const QString &exit)
@@ -1052,21 +1112,15 @@ void torkView::bwUpdated(const QString &in, const QString &out)
 
 }
 
-void torkView::streamProgram(const QString &stream, const QString &program)
+QPixmap torkView::streamProgram(const QString &program)
 {
 
-    streamItem* streamline;
-
-    if (!(streamline = streams[stream]))
-        return;
-
-    streamline->setText(1, program);
-
+    
     QString prog = KGlobal::iconLoader()->iconPath(program, KIcon::Small, true);
     if (prog.isEmpty())
-        streamline->setPixmap( 1, SmallIcon( "exec" ) );
+        return SmallIcon( "exec" );
     else
-        streamline->setPixmap( 1, SmallIcon( program ) );
+        return SmallIcon( program );
 
 }
 
@@ -1258,11 +1312,11 @@ void torkView::serverStatusUpdated(const QString &ip,const QString &fp, const QS
     QListViewItem* tm;
     
     if (update){
-        if (!( tm = serverList->findItem((fp),2)))
+        if (!( tm = torservers[fp]))
             tm = new QListViewItem(serverList, "", (server), fp, statuses);
     }else{
-
         tm = new QListViewItem(serverList, "", (server), fp, statuses);
+        torservers[fp] = tm;
     }
 
     QString cc;
@@ -1471,7 +1525,7 @@ void torkView::populateMenu()
     connect(paranoidmodetext, SIGNAL(leftClickedURL()), SIGNAL(aboutParanoidMode()));
 
 
-    paranoidmodeicon->setPixmap(SmallIcon("penguin"));
+    paranoidmodeicon->setPixmap(SmallIcon("tork_penguin"));
     paranoidmodetext->setText(i18n("In Normal mode!"));
 
     QStringList qconf;
@@ -1491,7 +1545,7 @@ void torkView::populateMenu()
     QLabel *headerLabel;
 
     //Firefox
-
+    firefoxitem = 0L;
 #ifndef LIVECD
     if (TorkConfig::availablePrograms().contains("firefox")){
 
@@ -1517,7 +1571,7 @@ void torkView::populateMenu()
         //firefoxitem->insertWidget(1,countries);
 
         buttonStart = new KURLLabel(firefoxitem);
-        buttonStart->setPixmap(SmallIcon("firefox"));
+        buttonStart->setPixmap(SmallIcon("info"));
         firefoxitem->insertHitWidget(0,buttonStart);
         connect(buttonStart, SIGNAL(leftClickedURL()), SLOT(downloadTorButton()));
 
@@ -1565,7 +1619,7 @@ void torkView::populateMenu()
 
 
     buttonStart = new KURLLabel(mixminionitem);
-    buttonStart->setPixmap(SmallIcon("kget"));
+    buttonStart->setPixmap(SmallIcon("info"));
     mixminionitem->insertHitWidget(0,buttonStart);
     connect(buttonStart, SIGNAL(leftClickedURL()), SLOT(downloadMixminion()));
 
@@ -1587,61 +1641,61 @@ void torkView::populateMenu()
     Anonymizer->insertItem(mixminionitem);
     connect(mixminionitem->icon, SIGNAL(leftClickedURL()), SLOT(sendAnonymousEmail()));
 
+    konqitem=0L;
     //Konqueror
-    konqitem = new HitWidget(QString::null, QString::null);
 #ifndef LIVECD
-    headerLabel = new QLabel(konqitem);
-    headerLabel->setText(i18n("Anonymous Browsing (with Konqueror)"));
-    font.setBold( true );
-    headerLabel->setFont( font );
-    konqitem->insertHeaderWidget(0,headerLabel);
-    
-    konqitem->setIcon("tork_konqueror_play");
+    if (TorkConfig::availablePrograms().contains("konqueror")){
+      konqitem = new HitWidget(QString::null, QString::null);
+      headerLabel = new QLabel(konqitem);
+      headerLabel->setText(i18n("Anonymous Browsing (with Konqueror)"));
+      font.setBold( true );
+      headerLabel->setFont( font );
+      konqitem->insertHeaderWidget(0,headerLabel);
+      
+      konqitem->setIcon("tork_konqueror_play");
 
-    if (TorkConfig::kDEUsesTor())
-        konqitem->icon->pixmap()->fill(Qt::red);
+      if (TorkConfig::kDEUsesTor())
+          konqitem->icon->pixmap()->fill(Qt::red);
 
-    konqitem->setDescriptionText("<qt>"+i18n("<b>Click the icon to launch an anonymous browsing session. </b><br>"
-                            )+"</qt>");
-    konqitem->setPropertiesText("<qt>"+i18n(
-                            "- This will also make any other Konqueror sessions you use anonymous. <br>"
-                            "- Konqueror windows that have anonymous browsing enabled are a funny green colour.<br>"
-                            "- Konqueror uses Privoxy in combination with Tor to anonymize your browsing. <br>"
-                            "- You can toggle this setting at any time using the Konqueror icon in the toolbar or the miniview.<br>"
-                            )+"</qt>");
+      konqitem->setDescriptionText("<qt>"+i18n("<b>Click the icon to launch an anonymous browsing session. </b><br>"
+                              )+"</qt>");
+      konqitem->setPropertiesText("<qt>"+i18n(
+                              "- This will also make any other Konqueror sessions you use anonymous. <br>"
+                              "- Konqueror windows that have anonymous browsing enabled are a funny green colour.<br>"
+                              "- Konqueror uses Privoxy in combination with Tor to anonymize your browsing. <br>"
+                              "- You can toggle this setting at any time using the Konqueror icon in the toolbar or the miniview.<br>"
+                              )+"</qt>");
 
-    konqitem->icon->setURL("konqueror");
+      konqitem->icon->setURL("konqueror");
 
-    buttonStart = new KURLLabel(konqitem);
-    buttonStart->setPixmap(SmallIcon("configure"));
-    konqitem->insertHitWidget(0,buttonStart);
-    connect(buttonStart, SIGNAL(leftClickedURL()), SIGNAL(showMyKonqueror()));
+      buttonStart = new KURLLabel(konqitem);
+      buttonStart->setPixmap(SmallIcon("configure"));
+      konqitem->insertHitWidget(0,buttonStart);
+      connect(buttonStart, SIGNAL(leftClickedURL()), SIGNAL(showMyKonqueror()));
 
-    buttonStart = new KURLLabel(konqitem);
-    buttonStart->setText(i18n("Configure Anonymous Konqueror"));
-    konqitem->insertHitWidget(1,buttonStart);
-    connect(buttonStart, SIGNAL(leftClickedURL()), SIGNAL(showMyKonqueror()));
+      buttonStart = new KURLLabel(konqitem);
+      buttonStart->setText(i18n("Configure Anonymous Konqueror"));
+      konqitem->insertHitWidget(1,buttonStart);
+      connect(buttonStart, SIGNAL(leftClickedURL()), SIGNAL(showMyKonqueror()));
 
-    configurePriv = new KURLLabel(konqitem);
-    configurePriv->setPixmap(SmallIcon("configure"));
-    konqitem->insertHitWidget(2,configurePriv);
-    connect(configurePriv, SIGNAL(leftClickedURL()), SIGNAL(configurePrivoxy()));
+      configurePriv = new KURLLabel(konqitem);
+      configurePriv->setPixmap(SmallIcon("configure"));
+      konqitem->insertHitWidget(2,configurePriv);
+      connect(configurePriv, SIGNAL(leftClickedURL()), SIGNAL(configurePrivoxy()));
 
-    configurePrivText = new KURLLabel(konqitem);
-    configurePrivText->setText(i18n("Configure Privoxy"));
-    konqitem->insertHitWidget(3,configurePrivText);
-    connect(configurePrivText, SIGNAL(leftClickedURL()), SIGNAL(configurePrivoxy()));
+      configurePrivText = new KURLLabel(konqitem);
+      configurePrivText->setText(i18n("Configure Privoxy"));
+      konqitem->insertHitWidget(3,configurePrivText);
+      connect(configurePrivText, SIGNAL(leftClickedURL()), SIGNAL(configurePrivoxy()));
 
-    Anonymizer->insertItem(konqitem);
-    connect(konqitem->icon, SIGNAL(leftClickedURL()), SIGNAL(konqWithTor()));
+      Anonymizer->insertItem(konqitem);
+      connect(konqitem->icon, SIGNAL(leftClickedURL()), SIGNAL(konqWithTor()));
+    }
     
 #endif
 
 
     operaitem = 0L;
-
-
-
 #ifndef LIVECD
 
     if (TorkConfig::availablePrograms().contains("opera")){
@@ -1668,11 +1722,10 @@ void torkView::populateMenu()
 #endif
 
 
+    hiddenservicesitem = 0L;
     //Hidden Services
     hiddenservicesitem = new HitWidget(QString::null, QString::null);
 
-#ifndef LIVECD
-
     headerLabel = new QLabel(hiddenservicesitem);
     headerLabel->setText(i18n("Anonymous Websites and Web Services"));
     font.setBold( true );
@@ -1697,7 +1750,6 @@ void torkView::populateMenu()
 
     Anonymizer->insertItem(hiddenservicesitem);
     connect(hiddenservicesitem->icon, SIGNAL(leftClickedURL()), SIGNAL(showMyHiddenServices()));
-#endif
 
 
     //Kopete
