@@ -1,7 +1,7 @@
 /***************************************************************************
- ** $Id: torkview.h,v 1.54 2008/06/02 10:38:27 hoganrobert Exp $
- *   Copyright (C) 2006 by Robert Hogan   *
- *   robert@roberthogan.net   *
+ ** $Id: torkview.h,v 1.57 2008/08/20 16:49:31 hoganrobert Exp $
+ *   Copyright (C) 2006 - 2008 Robert Hogan                                *
+ *   robert@roberthogan.net                                                *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -16,7 +16,7 @@
  *   You should have received a copy of the GNU General Public License     *
  *   along with this program; if not, write to the                         *
  *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.            *
+ *   51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.              *
  ***************************************************************************/
 
 
@@ -29,6 +29,7 @@
 #include "hitwidget.h"
 #include "kwidgetlistbox.h"
 #include "kerrylabel.h"
+#include "dndlistview.h"
 
 #include <qlistview.h>
 #include <qdragobject.h>
@@ -45,6 +46,8 @@ class QDragDropEvent;
 class KPassivePopup;
 class StreamOSD;
 class HitWidget;
+class streamItem;
+
 /**
  * This is the main view class for tork.  Most of the non-menu,
  * non-toolbar, and non-statusbar (e.g., non frame) GUI code should go
@@ -81,6 +84,7 @@ public:
     QStringList subnet16List(){ return m_subnet16List; }
     QValueList<int> countryList(){ return m_countryList; }
     StreamOSD* m_osd;
+    StreamOSD* m_nontorosd;
     void toggleAnonymizerTork(bool state);
     HitWidget* welcomeitem;
     HitWidget* hiddenservicesitem;
@@ -212,7 +216,7 @@ private slots:
     void guardStatusUpdated(const QString &ORID, const QString &status);
     void bwUpdated(const QString &in, const QString &out);
     void streamBwUpdated(const QString &stream, const QString &in, const QString &out);
-    void streamProgram(const QString &stream, const QString &port);
+    QPixmap streamProgram(const QString &port);
     void activeServersUpdated(const QStringList &servers);
     void displayError(const QString &,const QString &);
     void displayServer(const QString &,const QString &);
@@ -227,7 +231,7 @@ private:
 
     unsigned long readInterfaceNumValue(QString interface, const char* name);
     void setHiddenServicesText();
-    void parseStreamPort(const QString &,const QString &);
+    QString parseStreamPort(const QString &);
     void populateMenu();
 
     bool geoip_db;
@@ -260,12 +264,29 @@ private:
     typedef QMap<QString, QString> stringmap;
     stringmap entryGuards;
     stringmap streamPurpose;
+    stringmap portStream;
+
+    typedef QMap<QString, streamItem*> streamlist;
+    streamlist streams;
+    typedef QMap<QString, QListViewItem*> osdstreamlist;
+    osdstreamlist osdstreams;
+    osdstreamlist logstreams;
+    osdstreamlist torservers;
+    osdstreamlist circuitExits;
+    typedef QMap<QString, QPixmap> stringToPixmap;
+    stringToPixmap streamStatusIcon;
+    stringToPixmap cachedStreamIcon;
+
+    typedef QMap<QString, int> streamBw;
+    streamBw streamBwIn;
+    streamBw streamBwOut;
+
 
     QLabel *welcomeheaderLabel;
 
     unsigned int torbtx;
     unsigned int torbrx;
-
+    unsigned int progDisplayCounter;
 };
 
 void torkView::calcMaxSpeed() {
