@@ -1,6 +1,6 @@
 /***************************************************************************
- * $Id: update.cpp,v 1.23 2008/06/23 21:38:16 hoganrobert Exp $
- *   Copyright (C) 2006 by Robert Hogan                                    *
+ * $Id: update.cpp,v 1.25 2008/08/20 16:49:31 hoganrobert Exp $
+ *   Copyright (C) 2006 - 2008 Robert Hogan                                *
  *   robert@roberthogan.net                                                *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -16,7 +16,7 @@
  *   You should have received a copy of the GNU General Public License     *
  *   along with this program; if not, write to the                         *
  *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.            *
+ *   51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.              *
  ***************************************************************************/
 
 #include "update.h"
@@ -112,9 +112,9 @@ void TorkUpdate::downloadComponent(QString component, QString version, QString e
         int result = KMessageBox::questionYesNo(0, i18n( "You seem to have downloaded %1-%2 already (in %3/%4-%5). Would you like to skip re-downloading it and just try to compile it?").arg(component).arg(version).arg(location).arg(component).arg(version),i18n( "Compile %1" ).arg(component));
 
         switch (result) {
-            case 2 : 
+            case KMessageBox::Yes : 
                 download = true;break;
-            case 3 : 
+            case KMessageBox::No :
                 download = false;
         }
     }
